# MergeAccountingClient
The unified API for building rich integrations with multiple Accounting & Finance platforms.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.merge.dev/](https://www.merge.dev/)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/merge-api/merge-accounting-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/merge-api/merge-accounting-python.git`)

Then import the package:
```python
import MergeAccountingClient
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import MergeAccountingClient
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import MergeAccountingClient
from pprint import pprint
from MergeAccountingClient.api import account_details_api
from MergeAccountingClient.model.account_details import AccountDetails
# Defining the host is optional and defaults to https://api.merge.dev/api/accounting/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = MergeAccountingClient.Configuration(
    host = "https://api.merge.dev/api/accounting/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with MergeAccountingClient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = account_details_api.AccountDetailsApi(api_client)
    
    try:
        api_response = api_instance.account_details_retrieve()
        pprint(api_response)
    except MergeAccountingClient.ApiException as e:
        print("Exception when calling AccountDetailsApi->account_details_retrieve: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.merge.dev/api/accounting/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountDetailsApi* | [**account_details_retrieve**](docs/AccountDetailsApi.md#account_details_retrieve) | **GET** /account-details | 
*AccountTokenApi* | [**account_token_retrieve**](docs/AccountTokenApi.md#account_token_retrieve) | **GET** /account-token/{public_token} | 
*AccountsApi* | [**accounts_list**](docs/AccountsApi.md#accounts_list) | **GET** /accounts | 
*AccountsApi* | [**accounts_retrieve**](docs/AccountsApi.md#accounts_retrieve) | **GET** /accounts/{id} | 
*AddressesApi* | [**addresses_retrieve**](docs/AddressesApi.md#addresses_retrieve) | **GET** /addresses/{id} | 
*AttachmentsApi* | [**attachments_list**](docs/AttachmentsApi.md#attachments_list) | **GET** /attachments | 
*AttachmentsApi* | [**attachments_retrieve**](docs/AttachmentsApi.md#attachments_retrieve) | **GET** /attachments/{id} | 
*AvailableActionsApi* | [**available_actions_retrieve**](docs/AvailableActionsApi.md#available_actions_retrieve) | **GET** /available-actions | 
*BalanceSheetsApi* | [**balance_sheets_list**](docs/BalanceSheetsApi.md#balance_sheets_list) | **GET** /balance-sheets | 
*BalanceSheetsApi* | [**balance_sheets_retrieve**](docs/BalanceSheetsApi.md#balance_sheets_retrieve) | **GET** /balance-sheets/{id} | 
*CashFlowStatementsApi* | [**cash_flow_statements_list**](docs/CashFlowStatementsApi.md#cash_flow_statements_list) | **GET** /cash-flow-statements | 
*CashFlowStatementsApi* | [**cash_flow_statements_retrieve**](docs/CashFlowStatementsApi.md#cash_flow_statements_retrieve) | **GET** /cash-flow-statements/{id} | 
*CompanyInfoApi* | [**company_info_list**](docs/CompanyInfoApi.md#company_info_list) | **GET** /company-info | 
*CompanyInfoApi* | [**company_info_retrieve**](docs/CompanyInfoApi.md#company_info_retrieve) | **GET** /company-info/{id} | 
*ContactsApi* | [**contacts_list**](docs/ContactsApi.md#contacts_list) | **GET** /contacts | 
*ContactsApi* | [**contacts_retrieve**](docs/ContactsApi.md#contacts_retrieve) | **GET** /contacts/{id} | 
*CreditNotesApi* | [**credit_notes_list**](docs/CreditNotesApi.md#credit_notes_list) | **GET** /credit-notes | 
*CreditNotesApi* | [**credit_notes_retrieve**](docs/CreditNotesApi.md#credit_notes_retrieve) | **GET** /credit-notes/{id} | 
*DeleteAccountApi* | [**delete_account_create**](docs/DeleteAccountApi.md#delete_account_create) | **POST** /delete-account | 
*ExpensesApi* | [**expenses_list**](docs/ExpensesApi.md#expenses_list) | **GET** /expenses | 
*ExpensesApi* | [**expenses_retrieve**](docs/ExpensesApi.md#expenses_retrieve) | **GET** /expenses/{id} | 
*ForceResyncApi* | [**sync_status_resync_create**](docs/ForceResyncApi.md#sync_status_resync_create) | **POST** /sync-status/resync | 
*GenerateKeyApi* | [**generate_key_create**](docs/GenerateKeyApi.md#generate_key_create) | **POST** /generate-key | 
*IncomeStatementsApi* | [**income_statements_list**](docs/IncomeStatementsApi.md#income_statements_list) | **GET** /income-statements | 
*IncomeStatementsApi* | [**income_statements_retrieve**](docs/IncomeStatementsApi.md#income_statements_retrieve) | **GET** /income-statements/{id} | 
*InvoicesApi* | [**invoices_create**](docs/InvoicesApi.md#invoices_create) | **POST** /invoices | 
*InvoicesApi* | [**invoices_list**](docs/InvoicesApi.md#invoices_list) | **GET** /invoices | 
*InvoicesApi* | [**invoices_retrieve**](docs/InvoicesApi.md#invoices_retrieve) | **GET** /invoices/{id} | 
*IssuesApi* | [**issues_list**](docs/IssuesApi.md#issues_list) | **GET** /issues | 
*IssuesApi* | [**issues_retrieve**](docs/IssuesApi.md#issues_retrieve) | **GET** /issues/{id} | 
*ItemsApi* | [**items_list**](docs/ItemsApi.md#items_list) | **GET** /items | 
*ItemsApi* | [**items_retrieve**](docs/ItemsApi.md#items_retrieve) | **GET** /items/{id} | 
*JournalEntriesApi* | [**journal_entries_create**](docs/JournalEntriesApi.md#journal_entries_create) | **POST** /journal-entries | 
*JournalEntriesApi* | [**journal_entries_list**](docs/JournalEntriesApi.md#journal_entries_list) | **GET** /journal-entries | 
*JournalEntriesApi* | [**journal_entries_retrieve**](docs/JournalEntriesApi.md#journal_entries_retrieve) | **GET** /journal-entries/{id} | 
*LinkTokenApi* | [**link_token_create**](docs/LinkTokenApi.md#link_token_create) | **POST** /link-token | 
*LinkedAccountsApi* | [**linked_accounts_list**](docs/LinkedAccountsApi.md#linked_accounts_list) | **GET** /linked-accounts | 
*PassthroughApi* | [**passthrough_create**](docs/PassthroughApi.md#passthrough_create) | **POST** /passthrough | 
*PaymentsApi* | [**payments_list**](docs/PaymentsApi.md#payments_list) | **GET** /payments | 
*PaymentsApi* | [**payments_retrieve**](docs/PaymentsApi.md#payments_retrieve) | **GET** /payments/{id} | 
*PhoneNumbersApi* | [**phone_numbers_retrieve**](docs/PhoneNumbersApi.md#phone_numbers_retrieve) | **GET** /phone-numbers/{id} | 
*PurchaseOrdersApi* | [**purchase_orders_list**](docs/PurchaseOrdersApi.md#purchase_orders_list) | **GET** /purchase-orders | 
*PurchaseOrdersApi* | [**purchase_orders_retrieve**](docs/PurchaseOrdersApi.md#purchase_orders_retrieve) | **GET** /purchase-orders/{id} | 
*RegenerateKeyApi* | [**regenerate_key_create**](docs/RegenerateKeyApi.md#regenerate_key_create) | **POST** /regenerate-key | 
*ReportItemsApi* | [**report_items_retrieve**](docs/ReportItemsApi.md#report_items_retrieve) | **GET** /report-items/{id} | 
*SyncStatusApi* | [**sync_status_list**](docs/SyncStatusApi.md#sync_status_list) | **GET** /sync-status | 
*TaxRatesApi* | [**tax_rates_list**](docs/TaxRatesApi.md#tax_rates_list) | **GET** /tax-rates | 
*TaxRatesApi* | [**tax_rates_retrieve**](docs/TaxRatesApi.md#tax_rates_retrieve) | **GET** /tax-rates/{id} | 
*TrackingCategoriesApi* | [**tracking_categories_list**](docs/TrackingCategoriesApi.md#tracking_categories_list) | **GET** /tracking-categories | 
*TrackingCategoriesApi* | [**tracking_categories_retrieve**](docs/TrackingCategoriesApi.md#tracking_categories_retrieve) | **GET** /tracking-categories/{id} | 


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountDetails](docs/AccountDetails.md)
 - [AccountDetailsAndActions](docs/AccountDetailsAndActions.md)
 - [AccountDetailsAndActionsIntegration](docs/AccountDetailsAndActionsIntegration.md)
 - [AccountDetailsAndActionsStatusEnum](docs/AccountDetailsAndActionsStatusEnum.md)
 - [AccountIntegration](docs/AccountIntegration.md)
 - [AccountStatusEnum](docs/AccountStatusEnum.md)
 - [AccountToken](docs/AccountToken.md)
 - [AccountingAttachment](docs/AccountingAttachment.md)
 - [AccountingPhoneNumber](docs/AccountingPhoneNumber.md)
 - [Address](docs/Address.md)
 - [AddressTypeEnum](docs/AddressTypeEnum.md)
 - [AvailableActions](docs/AvailableActions.md)
 - [BalanceSheet](docs/BalanceSheet.md)
 - [CashFlowStatement](docs/CashFlowStatement.md)
 - [CategoriesEnum](docs/CategoriesEnum.md)
 - [CategoryEnum](docs/CategoryEnum.md)
 - [ClassificationEnum](docs/ClassificationEnum.md)
 - [CompanyInfo](docs/CompanyInfo.md)
 - [Contact](docs/Contact.md)
 - [CountryEnum](docs/CountryEnum.md)
 - [CreditNote](docs/CreditNote.md)
 - [CreditNoteStatusEnum](docs/CreditNoteStatusEnum.md)
 - [CurrencyEnum](docs/CurrencyEnum.md)
 - [DataPassthroughRequest](docs/DataPassthroughRequest.md)
 - [DebugModeLog](docs/DebugModeLog.md)
 - [DebugModelLogSummary](docs/DebugModelLogSummary.md)
 - [EndUserDetailsRequest](docs/EndUserDetailsRequest.md)
 - [ErrorValidationProblem](docs/ErrorValidationProblem.md)
 - [Expense](docs/Expense.md)
 - [ExpenseLine](docs/ExpenseLine.md)
 - [GenerateRemoteKeyRequest](docs/GenerateRemoteKeyRequest.md)
 - [IncomeStatement](docs/IncomeStatement.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceEndpointRequest](docs/InvoiceEndpointRequest.md)
 - [InvoiceLineItem](docs/InvoiceLineItem.md)
 - [InvoiceLineItemRequest](docs/InvoiceLineItemRequest.md)
 - [InvoiceRequest](docs/InvoiceRequest.md)
 - [InvoiceResponse](docs/InvoiceResponse.md)
 - [InvoiceTypeEnum](docs/InvoiceTypeEnum.md)
 - [Issue](docs/Issue.md)
 - [IssueStatusEnum](docs/IssueStatusEnum.md)
 - [Item](docs/Item.md)
 - [JournalEntry](docs/JournalEntry.md)
 - [JournalEntryEndpointRequest](docs/JournalEntryEndpointRequest.md)
 - [JournalEntryRequest](docs/JournalEntryRequest.md)
 - [JournalEntryResponse](docs/JournalEntryResponse.md)
 - [JournalLine](docs/JournalLine.md)
 - [JournalLineRequest](docs/JournalLineRequest.md)
 - [LinkToken](docs/LinkToken.md)
 - [MethodEnum](docs/MethodEnum.md)
 - [ModelOperation](docs/ModelOperation.md)
 - [PaginatedAccountDetailsAndActionsList](docs/PaginatedAccountDetailsAndActionsList.md)
 - [PaginatedAccountList](docs/PaginatedAccountList.md)
 - [PaginatedAccountingAttachmentList](docs/PaginatedAccountingAttachmentList.md)
 - [PaginatedBalanceSheetList](docs/PaginatedBalanceSheetList.md)
 - [PaginatedCashFlowStatementList](docs/PaginatedCashFlowStatementList.md)
 - [PaginatedCompanyInfoList](docs/PaginatedCompanyInfoList.md)
 - [PaginatedContactList](docs/PaginatedContactList.md)
 - [PaginatedCreditNoteList](docs/PaginatedCreditNoteList.md)
 - [PaginatedExpenseList](docs/PaginatedExpenseList.md)
 - [PaginatedIncomeStatementList](docs/PaginatedIncomeStatementList.md)
 - [PaginatedInvoiceList](docs/PaginatedInvoiceList.md)
 - [PaginatedIssueList](docs/PaginatedIssueList.md)
 - [PaginatedItemList](docs/PaginatedItemList.md)
 - [PaginatedJournalEntryList](docs/PaginatedJournalEntryList.md)
 - [PaginatedPaymentList](docs/PaginatedPaymentList.md)
 - [PaginatedPurchaseOrderList](docs/PaginatedPurchaseOrderList.md)
 - [PaginatedSyncStatusList](docs/PaginatedSyncStatusList.md)
 - [PaginatedTaxRateList](docs/PaginatedTaxRateList.md)
 - [PaginatedTrackingCategoryList](docs/PaginatedTrackingCategoryList.md)
 - [Payment](docs/Payment.md)
 - [PurchaseOrder](docs/PurchaseOrder.md)
 - [PurchaseOrderLineItem](docs/PurchaseOrderLineItem.md)
 - [PurchaseOrderStatusEnum](docs/PurchaseOrderStatusEnum.md)
 - [RemoteData](docs/RemoteData.md)
 - [RemoteDataRequest](docs/RemoteDataRequest.md)
 - [RemoteKey](docs/RemoteKey.md)
 - [RemoteKeyForRegenerationRequest](docs/RemoteKeyForRegenerationRequest.md)
 - [RemoteResponse](docs/RemoteResponse.md)
 - [ReportItem](docs/ReportItem.md)
 - [RequestFormatEnum](docs/RequestFormatEnum.md)
 - [StateEnum](docs/StateEnum.md)
 - [Status7d1Enum](docs/Status7d1Enum.md)
 - [SyncStatus](docs/SyncStatus.md)
 - [SyncStatusStatusEnum](docs/SyncStatusStatusEnum.md)
 - [TaxRate](docs/TaxRate.md)
 - [TrackingCategory](docs/TrackingCategory.md)
 - [ValidationProblemSource](docs/ValidationProblemSource.md)
 - [WarningValidationProblem](docs/WarningValidationProblem.md)


## Documentation For Authorization


## tokenAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

hello@merge.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in MergeAccountingClient.apis and MergeAccountingClient.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from MergeAccountingClient.api.default_api import DefaultApi`
- `from MergeAccountingClient.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import MergeAccountingClient
from MergeAccountingClient.apis import *
from MergeAccountingClient.models import *
```

